@@ -8,13 +8,21 @@ import javax.swing.table.AbstractTableModel;
 public class DesignTableModel extends AbstractTableModel {
 
 	List<Design> designs = new Vector<Design>();
+	CrossoverGUI gui;
 
-	public DesignTableModel() {
+	public DesignTableModel(CrossoverGUI gui) {
+		this.gui = gui;
 	}
 
 	public Class<?> getColumnClass(int columnIndex) {
-		if (columnIndex < 2) return String.class;
-		return Double.class;
+		switch (columnIndex) {
+		case 0: return String.class;
+		case 1: return Integer.class;
+		case 2: return Double.class;
+		case 3: return Boolean.class;
+		default: return null;
+		}
+		
 	}
 
 	public int getColumnCount() {
@@ -24,9 +32,9 @@ public class DesignTableModel extends AbstractTableModel {
 	public String getColumnName(int columnIndex) {
 		switch (columnIndex) {
 		case 0: return "Title";
-		case 1: return "Signature";
-		//case 2: return "av.eff.trt.pair";
-		case 2: return "av.eff.trt.pair.adj";
+		case 1: return "Sequences";
+		case 2: return "av.eff.trt.pair";
+		case 3: return "balanced";
 		default: return null;
 		}
 	}
@@ -39,9 +47,10 @@ public class DesignTableModel extends AbstractTableModel {
 		Design design = designs.get(rowIndex);
 		switch (columnIndex) {
 		case 0: return design.title;		                   
-		case 1: return design.getRSignature(); 
+		case 1: return design.s; // .getRSignature(); 
 		//case 2: return design.efficiencyUnadj;
-		case 2: return design.efficiencyAdj;
+		case 2:	return design.getEff(gui.jCBmodel.getSelectedIndex()+1, gui.getParam());
+		case 3: return false;
 		default: return null;
 		}
 	}
@@ -51,6 +60,7 @@ public class DesignTableModel extends AbstractTableModel {
 	}
 
 	public void setValueAt(Object aValue, int rowIndex, int columnIndex) {
+		//This method does not set the value - do we need it? Is throwing an error better?
 		fireTableStructureChanged();
 	}
 	
@@ -63,5 +73,5 @@ public class DesignTableModel extends AbstractTableModel {
 	public List<Design> getDesigns() {
 		return designs;
 	}
-
+	
 }
